@@ -518,7 +518,7 @@ message_summary *ReadOneMessageSummary(StrBuf *RawMessage, const char *DefaultSu
 			StrBufCutLeft(Buf, nBuf + 1);
 			Eval->f(Msg, Buf);
 		}
-		else syslog(1, "Don't know how to handle Message Headerline [%s]", ChrPtr(Buf));
+		else syslog(LOG_INFO, "Don't know how to handle Message Headerline [%s]", ChrPtr(Buf));
 	}
 	return Msg;
 }
@@ -1038,7 +1038,7 @@ void post_message(void)
 			StrBuf_ServGetln(Buf);
 			if (GetServerStatusMsg(Buf, NULL, 1, 2) != 2) {
 				/* You probably don't even have a dumb Drafts folder */
-				syslog(9, "%s:%d: server save to drafts error: %s\n", __FILE__, __LINE__, ChrPtr(Buf) + 4);
+				syslog(LOG_DEBUG, "%s:%d: server save to drafts error: %s\n", __FILE__, __LINE__, ChrPtr(Buf) + 4);
 				AppendImportantMessage(_("Saved to Drafts failed: "), -1);
 				display_enter();
 				FreeStrBuf(&Buf);
@@ -1112,7 +1112,7 @@ void post_message(void)
 		}
 		else 
 		{
-			syslog(9, "%s\n", ChrPtr(CmdBuf));
+			syslog(LOG_DEBUG, "%s\n", ChrPtr(CmdBuf));
 			serv_puts(ChrPtr(CmdBuf));
 			FreeStrBuf(&CmdBuf);
 
@@ -1149,7 +1149,7 @@ void post_message(void)
 				}
 				dont_post = lbstr("postseq");
 			} else {
-				syslog(9, "%s:%d: server post error: %s", __FILE__, __LINE__, ChrPtr(Buf) + 4);
+				syslog(LOG_DEBUG, "%s:%d: server post error: %s", __FILE__, __LINE__, ChrPtr(Buf) + 4);
 				AppendImportantMessage(ChrPtr(Buf) + 4, StrLength(Buf) - 4);
 				display_enter();
 				if (saving_to_drafts) gotoroom(WCC->CurRoom.name);
@@ -1204,16 +1204,16 @@ void upload_attachment(void) {
 	void *v;
 	wc_mime_attachment *att;
 
-	syslog(9, "upload_attachment()\n");
+	syslog(LOG_DEBUG, "upload_attachment()\n");
 	wc_printf("upload_attachment()<br>\n");
 
 	if (WCC->upload_length <= 0) {
-		syslog(9, "ERROR no attachment was uploaded\n");
+		syslog(LOG_DEBUG, "ERROR no attachment was uploaded\n");
 		wc_printf("ERROR no attachment was uploaded<br>\n");
 		return;
 	}
 
-	syslog(9, "Client is uploading %d bytes\n", WCC->upload_length);
+	syslog(LOG_DEBUG, "Client is uploading %d bytes\n", WCC->upload_length);
 	wc_printf("Client is uploading %d bytes<br>\n", WCC->upload_length);
 	att = malloc(sizeof(wc_mime_attachment));
 	memset(att, 0, sizeof(wc_mime_attachment ));
@@ -1322,7 +1322,7 @@ long l_rfca;
 
 const char *ReplyToModeStrings [3] = {
 	"reply",
-	"replyalle",
+	"replyall",
 	"forward"
 };
 typedef enum _eReplyToNodes {
