@@ -392,7 +392,7 @@ function roomListDropHandler(target, dropped) {
       for(msgId in currentlyMarkedRows) { //defined in summaryview.js
 	  msgIds += ","+msgId;
 	  if (msgIds.length > 800) {
-	      var mvCommand = encodeURI("g_cmd=MOVE " + msgIds + "|"+room+"|0");
+	      var mvCommand = "g_cmd=MOVE%20" + msgIds + "|"+encodeURIComponent(room)+"|0";
 	      new Ajax.Request("ajax_servcmd", {
 		  parameters: mvCommand,
 		  method: 'post',
@@ -401,7 +401,7 @@ function roomListDropHandler(target, dropped) {
 	  }
 
       }
-      var mvCommand = encodeURI("g_cmd=MOVE " + msgIds + "|"+room+"|0");
+      var mvCommand = "g_cmd=MOVE%20" + msgIds + "|"+encodeURIComponent(room)+"|0";
       new Ajax.Request('ajax_servcmd', {
 	  method: 'post',
 	  parameters: mvCommand,
