@@ -7,7 +7,7 @@ extern char *default_landing_page;
 
 int ClientGetLine(ParsedHttpHdrs *Hdr, StrBuf *Target);
 int client_read_to(ParsedHttpHdrs *Hdr, StrBuf *Target, int bytes, int timeout);
-void wc_backtrace(void);
+void wc_backtrace(long LogLevel);
 void ShutDownWebcit(void);
 void shutdown_ssl(void);
 
